@@ -24,7 +24,9 @@ QWaylandLayerShellIntegration::~QWaylandLayerShellIntegration()
 
 bool QWaylandLayerShellIntegration::initialize(QtWaylandClient::QWaylandDisplay *display)
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QWaylandShellIntegration::initialize(display);
+#endif
     display->addRegistryListener(registryLayer, this);
     return m_layerShell != nullptr;
 }
